==> valentina_0.7.53~dfsg.orig.tar.xz: valentina-v0.7.53/src/libs/vwidgets/fancytabbar/stylehelper.h <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef STYLEHELPER_H
#define STYLEHELPER_H

#include <QColor>
#include <QStyle>

class QPalette;
class QPainter;
class QRect;

// Note, this is exported but in a private header as qtopengl depends on it.
// We should consider adding this as a public helper function.
void qt_blurImage(QPainter *p, QImage &blurImage, qreal radius, bool quality, bool alphaOnly, int transposed = 0);

// Helper class holding all custom color values
class StyleHelper
{
public:
    static const unsigned int DEFAULT_BASE_COLOR = 0x666666;

    static auto sidebarFontSize() -> qreal;
    // This is our color table, all colors derive from baseColor
    static auto baseColor(bool lightColored = false) -> QColor;
    static auto panelTextColor(bool lightColored = false) -> QColor;
    static auto borderColor(bool lightColored = false) -> QColor;
    static auto sidebarHighlight() -> QColor;

    // Sets the base color and makes sure all top level widgets are updated
    static void setBaseColor(const QColor &newcolor);
    static void drawIconWithShadow(const QIcon &icon, const QRect &rect, QPainter *p, QIcon::Mode iconMode,
                                   int dipRadius = 3, const QColor &color = QColor(0, 0, 0, 130),
                                   const QPoint &dipOffset = QPoint(1, -2));
};

#endif // STYLEHELPER_H

==> valentina_1.0.0~dfsg.orig.tar.xz: valentina-v1.0.0/src/libs/vwidgets/fancytabbar/stylehelper.h <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef STYLEHELPER_H
#define STYLEHELPER_H

#include <QColor>
#include <QStyle>

class QPalette;
class QPainter;
class QRect;

// Note, this is exported but in a private header as qtopengl depends on it.
// We should consider adding this as a public helper function.
void qt_blurImage(QPainter *p, QImage &blurImage, qreal radius, bool quality, bool alphaOnly, int transposed = 0);

// Helper class holding all custom color values
class StyleHelper
{
public:
    static auto sidebarFontSize() -> qreal;
    // This is our color table, all colors derive from baseColor
    static auto baseColor(bool lightColored = false) -> QColor;
    static auto panelTextColor(bool lightColored = false) -> QColor;
    static auto borderColor(bool lightColored = false) -> QColor;
    static auto sidebarHighlight() -> QColor;

    // Sets the base color and makes sure all top level widgets are updated
    static void setBaseColor(const QColor &newcolor);
    static void drawIconWithShadow(const QIcon &icon, const QRect &rect, QPainter *p, QIcon::Mode iconMode,
                                   int dipRadius = 3, const QColor &color = QColor(0, 0, 0, 130),
                                   const QPoint &dipOffset = QPoint(1, -2));

private:
    static QColor m_baseColor;          // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
    static QColor m_requestedBaseColor; // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
};

#endif // STYLEHELPER_H
